@@ -7,8 +7,8 @@ class _Thread:
         pass
 
     @staticmethod
-    def run(function, args: list) -> list:
+    def run(func, args: list) -> list:
         num = len(args) if len(args) > 0 else 1
         if args:
             with concurrent.futures.ThreadPoolExecutor(max_workers=num) as exe:
-                return list(exe.map(function, args))
+                return list(exe.map(func, args))
